#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = require("commander");
const cli_spinners_1 = __importDefault(require("cli-spinners"));
const log_update_1 = __importDefault(require("log-update"));
const file_writers_1 = require("./templates/file-writers");
// @ts-ignore
const package_json_1 = require("../package.json");
let progressInterval;
const log = console.log;
const program = new commander_1.Command();
const printConsoleError = (message) => chalk_1.default.whiteBright.bgRed.bold(' ! ') + chalk_1.default.red.bold(' ' + message + '\n');
const sleep = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
const main = async () => {
    log(chalk_1.default.whiteBright.bgMagenta.bold(' Spectacle CLI '));
    program
        .name('create-spectacle')
        .description('CLI to bootstrap Spectacle decks')
        .version(package_json_1.version)
        .showHelpAfterError()
        .configureOutput({
        outputError: (message, write) => write(chalk_1.default.whiteBright.bgRed.bold(' ! ') +
            chalk_1.default.red.bold(' ' + message.replace('error: ', '')))
    })
        .requiredOption('-t, --type <type>', 'deck source type (choices: "tsx", "jsx", "mdx", "onepage")')
        .requiredOption('-n, --name [name]', 'name of presentation')
        .option('-l, --lang [lang]', 'language code for generated HTML document, default: en')
        .option('-p, --port [port]', 'port for webpack dev server, default: 3000')
        .parse(process.argv);
    let i = 0;
    const { type, name, lang = 'en', port = 3000 } = program.opts();
    progressInterval = setInterval(() => {
        const { frames } = cli_spinners_1.default.aesthetic;
        (0, log_update_1.default)(chalk_1.default.whiteBright.bgBlue.bold(` ${frames[(i = ++i % frames.length)]} `), chalk_1.default.blue.bold('Building Deck'));
    }, cli_spinners_1.default.dots.interval);
    await sleep(750);
    const fileOptions = {
        snakeCaseName: name.toLowerCase().replace(/([^a-z0-9]+)/gi, '-'),
        name,
        lang,
        port,
        enableTypeScriptSupport: type === 'tsx',
        spectacleVersion: package_json_1.devDependencies.spectacle
    };
    switch (type) {
        case 'jsx':
            await (0, file_writers_1.writeWebpackProjectFiles)(fileOptions);
            break;
        case 'tsx':
            await (0, file_writers_1.writeWebpackProjectFiles)(fileOptions);
            break;
        case 'onepage':
            await (0, file_writers_1.writeOnePageHTMLFile)(fileOptions);
            break;
    }
    clearInterval(progressInterval);
    (0, log_update_1.default)(chalk_1.default.whiteBright.bgGreen.bold(` \u2714 `), chalk_1.default.green.bold(`A new ${type} deck named ${name} was created.\n`));
};
main().catch((err) => {
    clearInterval(progressInterval);
    (0, log_update_1.default)(printConsoleError(err.message));
});
