"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeOnePageHTMLFile = exports.writeWebpackProjectFiles = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const promises_1 = require("fs/promises");
const html_1 = require("./html");
const one_page_1 = require("./one-page");
const webpack_1 = require("./webpack");
const babel_1 = require("./babel");
const package_1 = require("./package");
const index_1 = require("./index");
const tsconfig_1 = require("./tsconfig");
const writeWebpackProjectFiles = async ({ snakeCaseName, name, lang, port, enableTypeScriptSupport, spectacleVersion }) => {
    const outPath = path_1.default.resolve(process.cwd(), snakeCaseName);
    await (0, promises_1.rm)(outPath, { recursive: true, force: true });
    if ((0, fs_1.existsSync)(outPath)) {
        throw new Error(`Directory named ${snakeCaseName} already exists.`);
    }
    await (0, promises_1.mkdir)(outPath, { recursive: true });
    await (0, promises_1.writeFile)(`${snakeCaseName}/index.html`, (0, html_1.htmlTemplate)({ name, lang }));
    await (0, promises_1.writeFile)(`${snakeCaseName}/webpack.config.js`, (0, webpack_1.webpackTemplate)({ port, usesTypeScript: enableTypeScriptSupport }));
    await (0, promises_1.writeFile)(`${snakeCaseName}/.babelrc`, (0, babel_1.babelTemplate)({ enableTypeScriptSupport }));
    await (0, promises_1.writeFile)(`${snakeCaseName}/package.json`, (0, package_1.packageTemplate)({
        usesTypeScript: enableTypeScriptSupport,
        name: snakeCaseName,
        spectacleVersion
    }));
    await (0, promises_1.writeFile)(`${snakeCaseName}/index.${enableTypeScriptSupport ? 'tsx' : 'jsx'}`, (0, index_1.indexTemplate)({
        usesTypeScript: enableTypeScriptSupport,
        name
    }));
    enableTypeScriptSupport &&
        (await (0, promises_1.writeFile)(`${snakeCaseName}/tsconfig.json`, (0, tsconfig_1.tsconfigTemplate)()));
};
exports.writeWebpackProjectFiles = writeWebpackProjectFiles;
const writeOnePageHTMLFile = async ({ snakeCaseName, name, lang }) => {
    await (0, promises_1.writeFile)(`${snakeCaseName}.html`, (0, one_page_1.onePageTemplate)({ name, lang }));
};
exports.writeOnePageHTMLFile = writeOnePageHTMLFile;
